<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Form Recipients /////////////////////////
// Buttons:
define('FORM_RECIPIENTS_HEADING', "ترمیم فارم وصول کنندگان");
define('FORM_RECIPIENTS_EDIT_FORM_RECIPIENTS_BTN', "ترمیم فارم وصول کنندگان");
// Console Text:
define('FORM_RECIPIENTS_FORM_PAGE', "فارم پیج");
define('FORM_RECIPIENTS_MULTIPLE_RECIPIENTS_NOTE', "تم کوما سے ای میلز الگ کرکے ایک سے زائد وصول کنندہ مقرر کر سکتے ہیں.");
// Popup Messages:
define('FORM_RECIPIENTS_SAVING_RECIPIENT_MSG', "وصول کنندہ محفوظ کر رہا ہے ...");
define('VIEW_FORM_TABLES_HEADING', "فارم میزیں دیکھیں");
define('VIEW_FORM_TABLES_BTN', "فارم میزیں دیکھیں");
define('VIEW_FORM_TABLES_SELECT_TABLE', "ملاحظہ کرنے کیلئے میزیں منتخب کریں");
define('VIEW_FORM_TABLES_FILTER_READ', "پیغامات پڑھیں فلٹر");
?>